/*
 * Copyright (C) 2012 Michael Olbrich <m.olbrich@pengutonix.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

#ifndef MO_DAEMON_H
#define MO_DAEMON_H

#include <QtCore/QObject>
#include <QtCore/QTranslator>
#include <QtCore/QDir>

class QDeclarativeView;

class MoDaemon : public QObject
{
	Q_OBJECT
	Q_PROPERTY(QString locale READ locale WRITE setLocale NOTIFY localeChanged)
public:
	MoDaemon(int argc, char *argv[], QObject *parent = NULL);

	static MoDaemon *instance();

	bool parseArgs();

	void startDetach();

	void setupView(QDeclarativeView *engine);
	bool setupDBus(const QString &busName);

	QString locale() const;
	void setLocale(const QString &locale);

signals:
	void localeChanged(const QString &locale);

public slots:
	void detach();

private slots:
	void updateLocale(const QString &locale);

private:
	void addTheme(const QDir &dir);

private:
	bool m_detach;
	bool m_detached;
	QString m_pidFile;
	QString m_qml;
	QString m_locale;
	QString m_name;
	QTranslator m_translator;
};

#endif // MO_DAEMON_H

